@@ -119,7 +119,6 @@ fn build_rules_modifier(pair: Pair<Rule>) -> (rl::RuleKind, Option<String>) {
     };
 
     let comment = pairs.next().map(build_comment);
-
     (kind, comment)
 }
 
@@ -170,12 +169,7 @@ fn build_selector_sequence(
     };
 
     Ok((
-        ds::DaySelector {
-            year,
-            monthday,
-            week,
-            weekday,
-        },
+        ds::DaySelector { year, monthday, week, weekday },
         ts::TimeSelector::new(time),
         comment,
     ))
@@ -263,11 +257,7 @@ fn build_timespan(pair: Pair<Rule>) -> Result<ts::TimeSpan> {
         Some(other) => unexpected_token(other, Rule::timespan),
     };
 
-    Ok(ts::TimeSpan {
-        range: start..end,
-        repeats,
-        open_end,
-    })
+    Ok(ts::TimeSpan { range: start..end, repeats, open_end })
 }
 
 fn build_time(pair: Pair<Rule>) -> ts::Time {
@@ -385,11 +375,7 @@ fn build_weekday_range(pair: Pair<Rule>) -> Result<ds::WeekDayRange> {
         }
     };
 
-    Ok(ds::WeekDayRange::Fixed {
-        range: start..=end,
-        nth,
-        offset,
-    })
+    Ok(ds::WeekDayRange::Fixed { range: start..=end, nth, offset })
 }
 
 fn build_holiday(pair: Pair<Rule>) -> Result<ds::WeekDayRange> {
@@ -468,10 +454,7 @@ fn build_week(pair: Pair<Rule>) -> Result<ds::WeekRange> {
         expected: "an integer in [0, 255]".to_string(),
     })?;
 
-    Ok(ds::WeekRange {
-        range: start..=end.unwrap_or(start),
-        step,
-    })
+    Ok(ds::WeekRange { range: start..=end.unwrap_or(start), step })
 }
 
 // ---
@@ -500,10 +483,7 @@ fn build_monthday_range(pair: Pair<Rule>) -> Result<ds::MonthdayRange> {
             let start = build_month(pairs.next().unwrap());
             let end = pairs.next().map(build_month).unwrap_or(start);
 
-            Ok(ds::MonthdayRange::Month {
-                year,
-                range: start..=end,
-            })
+            Ok(ds::MonthdayRange::Month { year, range: start..=end })
         }
         Rule::date_from => {
             let start = build_date_from(pairs.next().unwrap());
@@ -560,10 +540,7 @@ fn build_date_offset(pair: Pair<Rule>) -> Result<ds::DateOffset> {
 
     let day_offset = pairs.next().map(build_day_offset).unwrap_or(Ok(0))?;
 
-    Ok(ds::DateOffset {
-        wday_offset,
-        day_offset,
-    })
+    Ok(ds::DateOffset { wday_offset, day_offset })
 }
 
 fn build_date_from(pair: Pair<Rule>) -> ds::Date {
@@ -604,11 +581,7 @@ fn build_date_to(pair: Pair<Rule>, from: ds::Date) -> Result<ds::Date> {
                     //       that this is allowed
                     return Err(Error::Unsupported("Easter followed by a day number"));
                 }
-                ds::Date::Fixed {
-                    mut year,
-                    mut month,
-                    day,
-                } => {
+                ds::Date::Fixed { mut year, mut month, day } => {
                     if day > daynum {
                         month = month.next();
 
@@ -619,11 +592,7 @@ fn build_date_to(pair: Pair<Rule>, from: ds::Date) -> Result<ds::Date> {
                         }
                     }
 
-                    ds::Date::Fixed {
-                        year,
-                        month,
-                        day: daynum,
-                    }
+                    ds::Date::Fixed { year, month, day: daynum }
                 }
             }
         }
@@ -657,10 +626,7 @@ fn build_year_range(pair: Pair<Rule>) -> Result<ds::YearRange> {
         expected: "an integer in [0, 2**16[".to_string(),
     })?;
 
-    Ok(ds::YearRange {
-        range: start..=end.unwrap_or(start),
-        step,
-    })
+    Ok(ds::YearRange { range: start..=end.unwrap_or(start), step })
 }
 
 // ---
